@@ -14,7 +14,7 @@ impl<R> IndexedReader<R>
 where
     R: BufRead + Seek,
 {
-    /// Create a indexed reader adapter.
+    /// Creates an indexed reader adapter.
     pub fn new(reader: Reader<R>, index: fai::Index) -> Self {
         Self { reader, index }
     }
@@ -25,7 +25,7 @@ where
     R: BufRead + Seek,
 {
     fn get(&mut self, name: &str) -> Option<io::Result<Record>> {
-        let region = Region::mapped(name, ..);
+        let region = Region::new(name, ..);
         Some(self.reader.query(&self.index, &region))
     }
 }
